"""
Fast and Versatile Alignments for Python.
"""

__pdoc__ = {
	'algorithm': False,
	'tests': False
}

from .gaps import *
from .solve import *
from .problems import *
